/* -*- Mode: IDL; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 2000
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Vidur Apparao <vidur@netscape.com> (original author)
 *   Johnny Stenback <jst@netscape.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either of the GNU General Public License Version 2 or later (the "GPL"),
 * or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "domstubs.idl"

/**
 * The nsIDOMRange interface is an interface to a DOM range object.
 *
 * For more information on this interface please see
 * http://www.w3.org/TR/DOM-Level-2-Traversal-Range/
 *
 * @status FROZEN
 */

[scriptable, uuid(a6cf90ce-15b3-11d2-932e-00805f8add32)]
interface nsIDOMRange : nsISupports
{
  readonly attribute nsIDOMNode       startContainer;
                                        // raises(DOMException) on retrieval

  readonly attribute long             startOffset;
                                        // raises(DOMException) on retrieval

  readonly attribute nsIDOMNode       endContainer;
                                        // raises(DOMException) on retrieval

  readonly attribute long             endOffset;
                                        // raises(DOMException) on retrieval

  readonly attribute boolean          collapsed;
                                        // raises(DOMException) on retrieval

  readonly attribute nsIDOMNode       commonAncestorContainer;
                                        // raises(DOMException) on retrieval

  void               setStart(in nsIDOMNode refNode, in long offset)
                                        raises(RangeException, DOMException);
  void               setEnd(in nsIDOMNode refNode, in long offset)
                                        raises(RangeException, DOMException);
  void               setStartBefore(in nsIDOMNode refNode)
                                        raises(RangeException, DOMException);
  void               setStartAfter(in nsIDOMNode refNode)
                                        raises(RangeException, DOMException);
  void               setEndBefore(in nsIDOMNode refNode)
                                        raises(RangeException, DOMException);
  void               setEndAfter(in nsIDOMNode refNode)
                                        raises(RangeException, DOMException);
  void               collapse(in boolean toStart)
                                        raises(DOMException);
  void               selectNode(in nsIDOMNode refNode)
                                        raises(RangeException, DOMException);
  void               selectNodeContents(in nsIDOMNode refNode)
                                        raises(RangeException, DOMException);

  // CompareHow
  const unsigned short      START_TO_START                 = 0;
  const unsigned short      START_TO_END                   = 1;
  const unsigned short      END_TO_END                     = 2;
  const unsigned short      END_TO_START                   = 3;

  short              compareBoundaryPoints(in unsigned short how,
                                           in nsIDOMRange sourceRange)
                                        raises(DOMException);
  void               deleteContents()
                                        raises(DOMException);
  nsIDOMDocumentFragment extractContents()
                                        raises(DOMException);
  nsIDOMDocumentFragment cloneContents()
                                        raises(DOMException);
  void               insertNode(in nsIDOMNode newNode)
                                        raises(DOMException, RangeException);
  void               surroundContents(in nsIDOMNode newParent)
                                        raises(DOMException, RangeException);
  nsIDOMRange        cloneRange()
                                        raises(DOMException);
  DOMString          toString()
                                        raises(DOMException);
  void               detach()
                                        raises(DOMException);
};
